# Tencent Cloud SDK for Python - Auth
A subpackage of the Tencent Cloud SDK for Python. This package implements related functions such as access credential type and signature calculation for Tencent Cloud SDK for Python.

Please note that this package does not depend on any other components of the Tencent Cloud SDK for Python and can be installed and used independently.

## Installation
With the Python package manager, you can quickly install the Tencent Cloud SDK for Python - Auth.

```bash
pip install tencent-cloud-sdk-auth
```

You can also try to build and install locally:

```bash
python setup.py install
```

## Other
If you encounter any problems during use, you are welcome to navigate to the [Issues](https://github.com/nobody-night/tencent-cloud-sdk-python/issues) page to submit and we will be happy to assist you with the problem.
